[![Build Status](https://travis-ci.org/cdusold/DriveLink.png?branch=master)](https://travis-ci.org/cdusold/DriveLink)

About
=====

A collection of memory conserving data structures designed to give peak performance
for on demand data usage while maintaining a constant use of RAM.

Available from `PyPI <https://pypi.python.org/pypi/DriveLink>`_, and easily installed through `pip install DriveLink`. Documentation available at `Read The Docs <http://drivelink.rtfd.org/>`_ and source available on `Github <https://github.com/cdusold/DriveLink>`_.
